import { request } from 'umi';
import { getDataBaseUrl } from '@/global_data';
/** 设备类型列表  */
export async function GetDeviceVesionPage(data) {
     return request(getDataBaseUrl()+`/api/devicevesion/page`, {
      method: 'POST',
      data: data,
    });
  }
    /** 添加设备类型  */
export async function AddDeviceVesion(data) {
    return request(getDataBaseUrl()+`/api/devicevesion/add`, {
     method: 'POST',
     data: data,
     // params: { ...params },
     // ...(options || {}),
   });
 }

   /** 删除设备类型  */
export async function DelDeviceVesion(data) {
    return request(getDataBaseUrl()+`​/api/devicevesion/delete`, {
     method: 'POST',
     data: data,
   });
 }

   /** 修改设备类型  */
export async function UpdateDeviceVesion(data) {
    return request(getDataBaseUrl()+`​/api/devicevesion/update`, {
     method: 'POST',
     data: data,
   });
 }
 export async function UpdateStatus(data) {
  return request(getDataBaseUrl()+`​/api/devicevesion/updatestatus`, {
   method: 'POST',
   data: data,
 });
}
/**获取产品 */
export async function GetProductList() {
  return request(getDataBaseUrl()+`/api/product/list`, {
    method: 'Get',
  });
}

  export async function GetCosRequestURL(data) {
    return request(getDataBaseUrl()+`/api/systemconfig/GetCosRequestSignURL`, {
     method: 'POST',
     data: data,
   });
  }